@@ -152,6 +152,7 @@ void MessagePoller::processNotification(const SyncNotification& notification)
 #if !defined(Q_OS_WIN32)
         case SYNC_ERROR_ID_INVALID_PATH_ON_WINDOWS:
 #endif
+        case SYNC_ERROR_ID_CASE_CONFLICT:
             LastSyncError::instance()->flagRepoSyncError(repo_id, err_id);
             break;
         }
@@ -200,17 +201,20 @@ void MessagePoller::processNotification(const SyncNotification& notification)
             break;
 #endif
         case SYNC_ERROR_ID_LIBRARY_TOO_LARGE:
-            msg = tr("Library is too large to sync.");
+            msg = tr("Library cannot be synced since it has too many files.");
             break;
         case SYNC_ERROR_ID_DEL_CONFIRMATION_PENDING:
             msg = tr("Waiting for confirmation to delete files");
             break;
         case SYNC_ERROR_ID_TOO_MANY_FILES:
-            msg = tr("Too many files in library");
+            msg = tr("Files cannot be uploaded to this library due to file number limit settings.");
             break;
         case SYNC_ERROR_ID_CHECKOUT_FILE:
             msg = tr("Failed to download file %1. Please check disk space or folder permissions").arg(path);
             break;
+        case SYNC_ERROR_ID_CASE_CONFLICT:
+            msg = tr("Path has character case conflict with existing file or folder. Will not be downloaded");
+            break;
         default:
             qWarning("Unknown sync error id %d", err_id);
             json_decref(object);
@@ -218,7 +222,7 @@ void MessagePoller::processNotification(const SyncNotification& notification)
         }
 
         seafApplet->trayIcon()->showMessage(title, msg, repo_id,
-                                            QString(""), QString(""), QSystemTrayIcon::Information, 10000, true);
+                                            QString(""), QString(""), QSystemTrayIcon::Information, true);
 
         json_decref(object);
 
