@@ -106,16 +106,14 @@ LoginDialog::LoginDialog(QWidget *parent) : QDialog(parent)
 #ifdef HAVE_SHIBBOLETH_SUPPORT
     setupShibLoginLink();
 #else
-    mShibLoginLink->hide();
+    mSSOBtn->hide();
 #endif
 }
 
 #ifdef HAVE_SHIBBOLETH_SUPPORT
 void LoginDialog::setupShibLoginLink()
 {
-    QString txt = QString("<a style=\"color:#777\" href=\"#\">%1</a>").arg(tr("Single Sign On"));
-    mShibLoginLink->setText(txt);
-    connect(mShibLoginLink, SIGNAL(linkActivated(const QString&)),
+    connect(mSSOBtn, SIGNAL(clicked()),
             this, SLOT(loginWithShib()));
 }
 #endif // HAVE_SHIBBOLETH_SUPPORT
@@ -180,6 +178,7 @@ void LoginDialog::disableInputs()
     mPassword->setEnabled(false);
     mSubmitBtn->setEnabled(false);
     mComputerName->setEnabled(false);
+    mSSOBtn->setEnabled(false);
 }
 
 void LoginDialog::enableInputs()
@@ -189,6 +188,7 @@ void LoginDialog::enableInputs()
     mPassword->setEnabled(true);
     mSubmitBtn->setEnabled(true);
     mComputerName->setEnabled(true);
+    mSSOBtn->setEnabled(true);
 }
 
 void LoginDialog::onNetworkError(const QNetworkReply::NetworkError& error, const QString& error_string)
@@ -475,7 +475,7 @@ void LoginDialog::clientSSOLinkSuccess(const QString& link)
     QString sso_link(link);
 
     qInfo() << "open sso link in browser:" << sso_link;
-    QDesktopServices::openUrl(QUrl(sso_link));
+    openUrl(QUrl(sso_link));
 
     QRegularExpression re("/client-sso/([^/]+)");
     QRegularExpressionMatch match = re.match(sso_link);
