@@ -6,8 +6,6 @@
 #include <vector>
 #include <QByteArray>
 
-typedef void DarkModeChangedCallback(bool value);
-
 namespace utils {
 namespace mac {
 // a list for os x versions https://support.apple.com/en-us/HT201260
@@ -29,9 +27,6 @@ bool get_auto_start();
 void set_auto_start(bool enabled);
 void copyTextToPasteboard(const QString &text);
 
-bool is_darkmode();
-void set_darkmode_watcher(DarkModeChangedCallback *cb);
-
 QString mainBundlePath();
 
 // load the missing part of ca certificates
